## scsk_dx_utils
- utils for SCSK Europe DX data team
- modules are in scskutils/ directory

## resources
https://packaging.python.org/en/latest/tutorials/packaging-projects/

## PYPI credentials
- user: emelas
- password: SCSKDXLondon

## PYPI page
https://pypi.org/project/SCSKutils/

## Install:
pip install SCSKutils

## Use:
from scskutils import module.py (at the moment, only have scskutils.py)
